<?php

namespace Litecms\News\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\News\Models\LatestNews;

class LatestNewsPolicy
{

    /**
     * Determine if the given user can view the latest_news.
     *
     * @param UserPolicy $user
     * @param LatestNews $latest_news
     *
     * @return bool
     */
    public function view(UserPolicy $user, LatestNews $latest_news)
    {
        if ($user->canDo('news.latest_news.view') && $user->isAdmin()) {
            return true;
        }

        return $latest_news->user_id == user_id() && $latest_news->user_type == user_type();
    }

    /**
     * Determine if the given user can create a latest_news.
     *
     * @param UserPolicy $user
     * @param LatestNews $latest_news
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('news.latest_news.create');
    }

    /**
     * Determine if the given user can update the given latest_news.
     *
     * @param UserPolicy $user
     * @param LatestNews $latest_news
     *
     * @return bool
     */
    public function update(UserPolicy $user, LatestNews $latest_news)
    {
        if ($user->canDo('news.latest_news.edit') && $user->isAdmin()) {
            return true;
        }

        return $latest_news->user_id == user_id() && $latest_news->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given latest_news.
     *
     * @param UserPolicy $user
     * @param LatestNews $latest_news
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LatestNews $latest_news)
    {
        return $latest_news->user_id == user_id() && $latest_news->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given latest_news.
     *
     * @param UserPolicy $user
     * @param LatestNews $latest_news
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LatestNews $latest_news)
    {
        if ($user->canDo('news.latest_news.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given latest_news.
     *
     * @param UserPolicy $user
     * @param LatestNews $latest_news
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LatestNews $latest_news)
    {
        if ($user->canDo('news.latest_news.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
